#ifndef __CRIA_ENUMERATIONS_H__
#define __CRIA_ENUMERATIONS_H__

#include <glib-object.h>

#include "block.h"

G_BEGIN_DECLS

